scan

package module
v0.0.0-...-5056288 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 1, 2026 License: MIT Imports: 15 Imported by: 1

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Build

func Build(ctx context.Context, pages []api.ExportPage, artistsEdition bool, fileName string) error

Build exports a PDF of the pages passed to it

func Dir

func Dir(ctx context.Context, dir string, scanCount int, knownSeries []string, skipTitles []string) ([]api.Issue, error)

Dir scans the given directory for PDF files and extracts episode details from each file. Deprecated: Use NewScanner and Scanner.Dir instead for better control.

func File

func File(ctx context.Context, fileName string, knownSeries []string, skipTitles []string) (api.Issue, error)

File scans the given file in the specified directory and extracts episode details. Deprecated: Use NewScanner and Scanner.File instead for better control.

func ReadCredits

func ReadCredits(ctx context.Context, fileName string, startingPage int, endingPage int) (api.Credits, error)

func Sanitise

func Sanitise(ctx context.Context, issues *[]api.Issue, knownTitles []string)

Types

type Scanner

type Scanner struct {
	// contains filtered or unexported fields
}

Scanner encapsulates scanning configuration and operations

func NewScanner

func NewScanner(knownSeries, skipTitles []string) *Scanner

NewScanner creates a new Scanner with the given configuration

func (*Scanner) Dir

func (s *Scanner) Dir(ctx context.Context, dir string, scanCount int) ([]api.Issue, error)

Dir scans the given directory for PDF files and extracts episode details from each file.

func (*Scanner) File

func (s *Scanner) File(ctx context.Context, fileName string) (api.Issue, error)

File scans a single PDF file and extracts episode details.

type Suggestion

type Suggestion struct {
	From string
	To   string
	Type SuggestionType
}

type SuggestionType

type SuggestionType int64
const (
	SeriesTitle SuggestionType = iota
	EpisodeTitle
)

Directories

Path Synopsis

Jump to