Documentation
¶
Index ¶
- func Build(ctx context.Context, pages []api.ExportPage, artistsEdition bool, ...) error
- func Dir(ctx context.Context, dir string, scanCount int, knownSeries []string, ...) ([]api.Issue, error)
- func File(ctx context.Context, fileName string, knownSeries []string, ...) (api.Issue, error)
- func ReadCredits(ctx context.Context, fileName string, startingPage int, endingPage int) (api.Credits, error)
- func Sanitise(ctx context.Context, issues *[]api.Issue, knownTitles []string)
- type Scanner
- type Suggestion
- type SuggestionType
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Dir ¶
func Dir(ctx context.Context, dir string, scanCount int, knownSeries []string, skipTitles []string) ([]api.Issue, error)
Dir scans the given directory for PDF files and extracts episode details from each file. Deprecated: Use NewScanner and Scanner.Dir instead for better control.
func File ¶
func File(ctx context.Context, fileName string, knownSeries []string, skipTitles []string) (api.Issue, error)
File scans the given file in the specified directory and extracts episode details. Deprecated: Use NewScanner and Scanner.File instead for better control.
func ReadCredits ¶
Types ¶
type Scanner ¶
type Scanner struct {
// contains filtered or unexported fields
}
Scanner encapsulates scanning configuration and operations
func NewScanner ¶
NewScanner creates a new Scanner with the given configuration
type Suggestion ¶
type Suggestion struct {
From string
To string
Type SuggestionType
}
type SuggestionType ¶
type SuggestionType int64
const ( SeriesTitle SuggestionType = iota EpisodeTitle )
Click to show internal directories.
Click to hide internal directories.